<?php
/**
 * @copyright: Copyright © 2020 Firebear Studio. All rights reserved.
 * @author   : Firebear Studio <fbeardev@gmail.com>
 */

namespace Firebear\PlatformSap\Model\Export\Adapter;

use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Filesystem;
use Magento\ImportExport\Model\Export\Adapter\Csv as AbstractAdapter;

/**
 * Class Customer
 * @package Firebear\PlatformSap\Model\Export\Adapter
 */
class Customer extends AbstractAdapter
{
    /**
     * Adapter Data
     *
     * @var []
     */
    protected $_data;

    /**
     * @var \Firebear\ImportExport\Model\Export\Adapter\Gateway\Customer
     */
    protected $gateway;

    /**
     * @var \Magento\Directory\Model\CountryFactory
     */
    private $countryFactory;

    /**
     * Customer constructor.
     * @param Filesystem $filesystem
     * @param Gateway\Customer $gateway
     * @param \Magento\Directory\Model\CountryFactory $countryFactory
     * @param null $destination
     * @param string $destinationDirectoryCode
     * @param array $data
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function __construct(
        Filesystem $filesystem,
        \Firebear\PlatformSap\Model\Export\Adapter\Gateway\Customer $gateway,
        \Magento\Directory\Model\CountryFactory $countryFactory,
        $destination = null,
        $destinationDirectoryCode = DirectoryList::VAR_DIR,
        array $data = []
    ) {
        $this->gateway = $gateway;
        $this->countryFactory = $countryFactory;
        $this->_data = $data;
        if (isset($data['behavior_data'])) {
            $data = $data['behavior_data'];
            $this->gateway->setBehaviorData($data);
            $this->_delimiter = $data['separator'] ?? $this->_delimiter;
            $this->_enclosure = $data['enclosure'] ?? $this->_enclosure;
        }
        
        parent::__construct(
            $filesystem,
            $destination,
            $destinationDirectoryCode
        );
    }
    
    /**
     * Write row data to source file.
     *
     * @param array $rowData
     * @throws \Exception
     * @return $this
     */
    public function writeRow(array $rowData)
    {
        $rowData['entity'] = $this->_data['entity'];
        $this->gateway->exportCustomer($rowData);

        if (null === $this->_headerCols) {
            $this->setHeaderCols(array_keys($rowData));
        }
        if (null === $this->_headerCols) {
            $this->_headerCols = [];
        }
        $this->_fileHandler->writeCsv(
            array_merge($this->_headerCols, array_intersect_key($rowData, $this->_headerCols)),
            $this->_delimiter,
            $this->_enclosure
        );
        return $this;
    }
}
