<?php
 /**
  * Copyright © Firebear Studio, Inc. All rights reserved.
  * See COPYING.txt for license details.
  */
namespace Firebear\PlatformSap\Model\Import\Source;

use Magento\Framework\Exception\LocalizedException;

/**
 * Sap product source
 */
class Product extends AbstractSource
{
    /**
     * @var \Firebear\PlatformSap\Model\Source\Gateway\Product
     */
    protected $gateway;

    /**
     * Config data
     *
     * @var array
     */
    protected $_data = [];

    /**
     * @var \Magento\Framework\App\RequestInterface
     */
    protected $request;

    /**
     * Product constructor.
     * @param Gateway\Product $gateway
     * @param \Magento\Framework\App\RequestInterface $request
     * @param null $data
     * @throws \Exception
     */
    public function __construct(
        \Firebear\PlatformSap\Model\Import\Source\Gateway\Product $gateway,
        \Magento\Framework\App\RequestInterface $request,
        $data = null
    ) {
        $this->gateway = $gateway;
        $this->request = $request;
        $this->parseEntities($data);
    }

    /**
     * @param $data
     * @return array|bool
     * @throws \Exception
     */
    protected function parseEntities($data)
    {
        $this->entities = parent::parseEntities($data);
        if (!empty($this->entities)) {
            foreach ($this->entities as $key => $entity) {
                if (isset($entity['ItemCode'])) {
                    $this->entities[$key]['sku'] = $entity['ItemCode'];
                    $this->entities[$key]['sap_id'] = $entity['ItemCode'];
                }
                if (isset($entity['ItemName'])) {
                    $this->entities[$key]['name'] = $entity['ItemName'];
                }
                if (isset($entity['ItmsGrpNam']) && !empty($entity['ItmsGrpNam'])) {
                    if (strpos($entity['ItmsGrpNam'], $data['categories_separator']) !== false) {
                        $categories = explode($data['categories_separator'], $entity['ItmsGrpNam']);
                        $this->entities[$key]['categories'] = '';
                        foreach ($categories as $category) {
                            $this->entities[$key]['categories'] .=
                                \Firebear\PlatformSap\Model\Import\Source\Category::DEFAULT_CATEGORY_NAME;
                            $this->entities[$key]['categories'] .= $data['category_levels_separator'];
                            $this->entities[$key]['categories'] .= trim($category) . $data['categories_separator'];
                        }
                        $this->entities[$key]['categories'] = substr(
                            $this->entities[$key]['categories'],
                            0,
                            -1
                        );
                    } else {
                        $this->entities[$key]['categories'] =
                            \Firebear\PlatformSap\Model\Import\Source\Category::DEFAULT_CATEGORY_NAME;
                        $this->entities[$key]['categories'] .= $data['category_levels_separator'];
                        $this->entities[$key]['categories'] .= $entity['ItmsGrpNam'];
                    }
                }
                if (isset($entity['FirmName'])) {
                    $this->entities[$key]['manufacturer'] = $entity['FirmName'];
                }
                if (isset($entity['Weight'])) {
                    $this->entities[$key]['weight'] = $entity['Weight'];
                }
                if (isset($entity['BuyUnitMsr'])) {
                    $this->entities[$key]['unit_of_measure'] = $entity['BuyUnitMsr'];
                }
                if (isset($entity['Price'])) {
                    $this->entities[$key]['price'] = $entity['Price'];
                }
                if (isset($entity['SpecialPrice']) && $entity['SpecialPrice'] > 0) {
                    $this->entities[$key]['special_price'] = $entity['SpecialPrice'];
                }
                if (isset($entity['SpecialPriceFromDate'])) {
                    $this->entities[$key]['special_price_from_date'] = $entity['SpecialPriceFromDate'];
                }
                if (isset($entity['SpecialPriceToDate'])) {
                    $this->entities[$key]['special_price_to_date'] = $entity['SpecialPriceToDate'];
                }
                if (isset($entity['Qty_Available'])) {
                    $this->entities[$key]['qty'] = $entity['Qty_Available'];
                }
                $this->entities[$key]['product_type'] = 'simple';
                $this->entities[$key]['product_websites'] = 'base';
                $this->entities[$key]['_attribute_set'] = 'Default';
            }
        }
        $this->_colNames = array_keys($this->entities[0] ?? []);
        return $this->entities;
    }
}
