<?php
 /**
  * Copyright © Firebear Studio, Inc. All rights reserved.
  * See COPYING.txt for license details.
  */
namespace Firebear\PlatformSap\Model\Import\Source;

use Firebear\PlatformSap\Model\Import\Source\Gateway\ProductPriceAndStock as ProductPriceGateway;
use Magento\Framework\App\RequestInterface;
use Magento\ImportExport\Model\Import;

/**
 * Sap product price source
 */
class ProductPriceAndStock extends AbstractSource
{
    /**
     * @var \Firebear\PlatformSap\Model\Source\Gateway\Product
     */
    protected $gateway;

    /**
     * Config data
     *
     * @var array
     */
    protected $_data = [];

    /**
     * @var \Magento\Framework\App\RequestInterface
     */
    protected $request;

    /**
     * ProductPrice constructor.
     * @param ProductPriceGateway $gateway
     * @param RequestInterface $request
     * @param null $data
     * @throws \Exception
     */
    public function __construct(
        ProductPriceGateway $gateway,
        RequestInterface $request,
        $data = null
    ) {
        $this->gateway = $gateway;
        $this->request = $request;
        $this->parseEntities($data);
    }

    /**
     * @param $data
     * @return array|bool
     * @throws \Exception
     */
    protected function parseEntities($data)
    {
        $result = [];
        $this->entities = parent::parseEntities($data);
        if (!empty($this->entities)) {
            foreach ($this->entities as $key => $entity) {
                if ($this->validateData($entity,'ItemCode')) {
                    $result[$key]['sku'] = $entity['ItemCode'];
                }
                if ($this->validateData($entity,'Price')) {
                    $result[$key]['price'] = $entity['Price'];
                }
                if ($this->validateData($entity,'SpecialPrice') && $entity['SpecialPrice'] > 0) {
                    $result[$key]['special_price'] = $entity['SpecialPrice'];
                } else {
                    $result[$key]['special_price'] = Import::DEFAULT_EMPTY_ATTRIBUTE_VALUE_CONSTANT;
                }
                if ($this->validateData($entity,'SpecialPriceFromDate')) {
                    $result[$key]['special_price_from_date'] = $entity['SpecialPriceFromDate'];
                } else {
                    $result[$key]['special_price_from_date'] = Import::DEFAULT_EMPTY_ATTRIBUTE_VALUE_CONSTANT;
                }
                if ($this->validateData($entity,'SpecialPriceToDate')) {
                    $result[$key]['special_price_to_date'] = $entity['SpecialPriceToDate'];
                } else {
                    $result[$key]['special_price_to_date'] = Import::DEFAULT_EMPTY_ATTRIBUTE_VALUE_CONSTANT;
                }
                if ($this->validateData($entity,'Qty_Available')) {
                    $result[$key]['qty'] = $entity['Qty_Available'];
                }
            }
        }
        $this->entities = $result;
        $this->_colNames = array_keys($this->entities[0] ?? []);
        return $this->entities;
    }
}
