<?php
/**
 * @copyright: Copyright © 2021 Firebear Studio. All rights reserved.
 * @author   : Firebear Studio <fbeardev@gmail.com>
 */

namespace Firebear\PlatformSap\Model;

use Magento\Sales\Api\Data\OrderInterface;
use Magento\Sales\Model\ResourceModel\Metadata;
use Firebear\PlatformSap\Api\OrderRepositoryInterface;
use Magento\Sales\Model\OrderRepository as BaseOrderRepository;
use Magento\Sales\Model\OrderFactory;

/**
 * OrderRepository model
 */
class OrderRepository implements OrderRepositoryInterface
{
    /**
     * @var Metadata
     */
    protected $metadata;

    /**
     * @var BaseOrderRepository
     */
    protected $orderRepository;

    /**
     * @var OrderFactory
     */
    protected $orderFactory;

    /**
     * @var OrderInterface[]
     */
    protected $registry = [];

    /**
     * OrderRepository constructor.
     * @param Metadata $metadata
     */
    public function __construct(
        Metadata $metadata,
        BaseOrderRepository $orderRepository,
        OrderFactory $orderFactory
    ) {
        $this->metadata = $metadata;
        $this->orderRepository = $orderRepository;
        $this->orderFactory = $orderFactory;
    }

    /**
     * @param OrderInterface $entity
     * @return OrderInterface|mixed
     */
    public function save(\Magento\Sales\Api\Data\OrderInterface $entity)
    {
        $orderIncrementId = $entity->getIncrementId();
        $order = $this->orderFactory->create()->loadByAttribute(
            \Magento\Sales\Api\Data\OrderInterface::INCREMENT_ID,
            $orderIncrementId
        );

        if (!empty($order->getId())) {
            $entity->setEntityId($order->getId());
        }

        return $this->orderRepository->save($entity);
    }
}
