<?php
/**
 * @copyright: Copyright © 2020 Firebear Studio GmbH. All rights reserved.
 */

namespace Firebear\PlatformSap\Observer;

use Magento\Customer\Model\ResourceModel\CustomerRepository;
use Magento\Customer\Model\Session;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer as EventObserver;
use Firebear\PlatformSap\Model\Customer\UpdatePublisher;

class CustomerRegisterSuccessObserver implements ObserverInterface
{
    /**
     * @var UpdatePublisher
     */
    private $customerUpdatePublisher;

    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    /**
     * @var Session
     */
    private $session;

    /**
     * @var CustomerRepository
     */
    private $customerRepository;

    /**
     * CustomerRegisterSuccessObserver constructor.
     * @param UpdatePublisher $orderUpdatePublisher
     * @param ScopeConfigInterface $scopeConfig
     * @param Session $session
     * @param CustomerRepository $customerRepository
     */
    public function __construct(
        UpdatePublisher $orderUpdatePublisher,
        ScopeConfigInterface $scopeConfig,
        Session $session,
        CustomerRepository $customerRepository
    ) {
        $this->customerUpdatePublisher = $orderUpdatePublisher;
        $this->scopeConfig = $scopeConfig;
        $this->session = $session;
        $this->customerRepository = $customerRepository;
    }

    /**
     * @param EventObserver $observer
     */
    public function execute(EventObserver $observer)
    {
        if ($this->scopeConfig->getValue('firebear_importexport/sap/export_customers')) {
            $orderId = $this->session->getSapDelegatedNewCustomerData(true);
            if (empty($orderId)) {
                $customer = $observer->getEvent()->getCustomer();
                $customer = $this->customerRepository->get($customer->getEmail());
                $this->customerUpdatePublisher->execute($customer);
            }
        }
    }
}
