<?php
/**
 * @copyright: Copyright © 2020 Firebear Studio. All rights reserved.
 * @author   : Firebear Studio <fbeardev@gmail.com>
 */

namespace Firebear\PlatformSap\Plugin\Button;

use Magento\Backend\Block\Widget\Button\ButtonList;
use Magento\Framework\View\Element\AbstractBlock;

/**
 * Class ToolbarPlugin
 * @package Firebear\PlatformSap\Plugin\Button
 */
class ToolbarPlugin
{

    /**
     * Add Sync with SAP button.
     *
     * @param \Magento\Backend\Block\Widget\Button\ToolbarInterface $subject
     * @param \Magento\Framework\View\Element\AbstractBlock $context
     * @param \Magento\Backend\Block\Widget\Button\ButtonList $buttonList
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function beforePushButtons(
        \Magento\Backend\Block\Widget\Button\ToolbarInterface $subject,
        AbstractBlock $context,
        ButtonList $buttonList
    ): void {
        $nameInLayout = $context->getNameInLayout();
        $order = $this->getOrder($nameInLayout, $context);
        if ($order) {
            $message = __('Are you sure you want to sync order with SAP?');
            $url = $context->getUrl('importsap/order/sync');
            $buttonList->add(
                'sync_with_sap',
                [
                    'label' => __('Sync with SAP'),
                    'class' => 'sync-with-sap',
                    'onclick' => "confirmSetLocation('{$message}', '{$url}')"
                ]
            );
        }
    }

    /**
     * Extract order data from context.
     *
     * @param string $nameInLayout
     * @param AbstractBlock $context
     * @return array|null
     */
    private function getOrder(string $nameInLayout, AbstractBlock $context)
    {
        $order = null;
        if ('sales_order_edit' == $nameInLayout) {
            $order = $context->getOrder();
        }
        return $order;
    }
}
