<?php
/**
 * @copyright: Copyright © 2020 Firebear Studio. All rights reserved.
 * @author   : Firebear Studio <fbeardev@gmail.com>
 */

namespace Firebear\PlatformSap\Plugin;

use Firebear\PlatformSap\Model\Customer\UpdatePublisher;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Backend\App\Action;
use Magento\Framework\ObjectManagerInterface;
use Magento\Customer\Model\CustomerRegistry;

/**
 * Class CustomerUpdatePlugin
 * @package Firebear\PlatformSap\Plugin
 */
class CustomerUpdateAdminhtmlPlugin
{
    /**
     * @var UpdatePublisher
     */
    private $customerUpdatePublisher;

    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    /**
     * @var ObjectManagerInterface
     */
    private $objectManager;

    /**
     * CustomerUpdateAdminhtmlPlugin constructor.
     * @param UpdatePublisher $customerUpdatePublisher
     * @param ScopeConfigInterface $scopeConfig
     * @param ObjectManagerInterface $objectManager
     */
    public function __construct(
        UpdatePublisher $customerUpdatePublisher,
        ScopeConfigInterface $scopeConfig,
        ObjectManagerInterface $objectManager
    ) {
        $this->customerUpdatePublisher = $customerUpdatePublisher;
        $this->scopeConfig = $scopeConfig;
        $this->objectManager = $objectManager;
    }

    /**
     * @param Action $subject
     * @param \Magento\Framework\Controller\Result\Json $result
     * @return \Magento\Framework\Controller\Result\Json
     * @throws \Magento\Framework\Exception\LocalizedException
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function afterExecute(
        Action $subject,
        \Magento\Framework\Controller\Result\Json $result
    ) {
        if ($this->scopeConfig->getValue('firebear_importexport/sap/export_customers')) {
            $customerId = $subject->getRequest()->getParam('parent_id', false);
            $customerRegistry = $this->objectManager->create(CustomerRegistry::class);
            $customer = $customerRegistry->retrieve($customerId);
            $this->customerUpdatePublisher->execute($customer->getDataModel());
        }
        return $result;
    }
}
