<?php
/**
 * @copyright: Copyright © 2021 Firebear Studio. All rights reserved.
 * @author   : Firebear Studio <fbeardev@gmail.com>
 */

namespace Firebear\PlatformSap\Setup\Patch\Data;

use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Framework\Setup\Patch\DataPatchInterface;
use Magento\Framework\Setup\Patch\PatchRevertableInterface;
use Magento\Sales\Setup\SalesSetupFactory;

/**
 * Create custom sales order, invoice, shipment and credit_memo attributes
 */
class UpdateSalesAttributes implements DataPatchInterface, PatchRevertableInterface
{
    const ATTRIBUTE_CODE = 'sap_id';

    /**
     * @var ModuleDataSetupInterface
     */
    private $moduleDataSetup;

    /**
     * @var SalesSetupFactory
     */
    private $salesSetupFactory;

    /**
     * UpdateSalesAttributes constructor.
     * @param ModuleDataSetupInterface $moduleDataSetup
     * @param SalesSetupFactory $salesSetupFactory
     */
    public function __construct(
        ModuleDataSetupInterface $moduleDataSetup,
        SalesSetupFactory $salesSetupFactory
    ) {
        $this->moduleDataSetup = $moduleDataSetup;
        $this->salesSetupFactory = $salesSetupFactory;
    }

    /**
     * {@inheritdoc}
     * @SuppressWarnings(PHPMD.ExcessiveMethodLength)
     */
    public function apply()
    {
        $salesInstaller = $this->salesSetupFactory->create(
            ['resourceName' => 'sales_setup', 'setup' => $this->moduleDataSetup]
        );
        $salesInstaller->addAttribute(
            'order',
            self::ATTRIBUTE_CODE,
            ['type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT]
        );
        $salesInstaller->addAttribute(
            'invoice',
            self::ATTRIBUTE_CODE,
            ['type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT]
        );
        $salesInstaller->addAttribute(
            'shipment',
            self::ATTRIBUTE_CODE,
            ['type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT]
        );
        $salesInstaller->addAttribute(
            'creditmemo',
            self::ATTRIBUTE_CODE,
            ['type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT]
        );
    }

    /**
     * @return array|string[]
     */
    public static function getDependencies()
    {
        return [];
    }

    /**
     * @return array|string[]
     */
    public function getAliases()
    {
        return [];
    }

    /**
     *  Remove custom sales attributes
     */
    public function revert()
    {
        $salesInstaller = $this->salesSetupFactory->create(
            ['resourceName' => 'sales_setup', 'setup' => $this->moduleDataSetup]
        );
        $salesInstaller->removeAttribute(
            'order',
            self::ATTRIBUTE_CODE
        );
        $salesInstaller->removeAttribute(
            'invoice',
            self::ATTRIBUTE_CODE
        );
        $salesInstaller->removeAttribute(
            'shipment',
            self::ATTRIBUTE_CODE
        );
        $salesInstaller->removeAttribute(
            'creditmemo',
            self::ATTRIBUTE_CODE
        );
    }
}
